.. _tutorial_nipy:

=======================
Using SPM and nipy for analysis
=======================

Copy over the spm_tutorial.py script from the examples folder or cut
and paste the document included below into a file. Then run the
tutorial from inside the nipype tutorial directory.

::
        python nipy_tutorial.py


.. include:: ../examples/nipy_tutorial.rst

.. include:: ../links_names.txt
